repo stringclasses 15
values | fix_commit stringlengths 40 40 | buggy_commit stringlengths 40 40 | message stringlengths 3 64.3k | files listlengths 1 300 | timestamp timestamp[s]date 2013-03-13 20:45:00 2026-04-11 07:48:46 |
|---|---|---|---|---|---|
facebook/react | 6fc3333b685657c8e6425df9fcb4fe1ce7374d40 | 535c038d15d21f33e678187410d658456cc0ce39 | Add $FlowFixMe to fix React Native DiffTrain (#26841) | [
{
"path": "scripts/rollup/shims/react-native/ReactNativeViewConfigRegistry.js",
"patch": "@@ -106,6 +106,7 @@ exports.get = function (name: string): ViewConfig {\n 'View config getter callback for component `%s` must be a function (received `%s`).%s',\n name,\n callback === null ? 'n... | 2023-05-24T16:42:16 |
huggingface/transformers | 1618d44b9295361607ec74d7be860ba886aac039 | 1e31876d0eef7d046ad5d2813f67a73026fcec9c | Add Higgs Audio V2 Model (#40294)
* add higgs audio v2
* make some changes
* update tokenizer test
* reformat
* fix
* fix
* update
* fix
* fix typo
* fix
* fix import
* remove audio attention and whisper
* add model
* fix
* fix
* fix
* change the place for delay pattern utilities
* update convert
* r... | [
{
"path": "docs/source/en/_toctree.yml",
"patch": "@@ -977,6 +977,10 @@\n title: GLM-ASR\n - local: model_doc/granite_speech\n title: GraniteSpeech\n+ - local: model_doc/higgs_audio_v2\n+ title: Higgs Audio V2\n+ - local: model_doc/higgs_audio_v2_tokenizer\n+ ti... | 2026-02-19T17:19:19 |
ggml-org/llama.cpp | d1f82e382ddf67f63ee0fd28ae613456cbb23481 | 0988accf824e817d0e3db55c05f5f2954fbfe505 | Fix rtl text rendering (#21382)
* Fix Arabic RTL text rendering in web UI
- Add dir='auto' attributes to markdown containers and blocks
- Implement post-processing to add dir='auto' to all text elements
- Replace directional CSS properties with logical properties for proper RTL list alignment
- Ensure bidirectional t... | [
{
"path": "tools/server/public/index.html",
"patch": "@@ -18,7 +18,7 @@\n \t\t<div style=\"display: contents\">\n \t\t\t<script>\n \t\t\t\t{\n-\t\t\t\t\t__sveltekit_1trm5n9 = {\n+\t\t\t\t\t__sveltekit_1y361v9 = {\n \t\t\t\t\t\tbase: new URL('.', location).pathname.slice(0, -1)\n \t\t\t\t\t};\n ",
"addit... | 2026-04-07T09:37:20 |
electron/electron | 0f087127de7228ad77dbaba524421932c46b4ef8 | b9c0166b4912dbba344a43d25a310f5a86633ace | chore: fix patch conflicts from 37b7e347 (#33818)
* chore: update patches
* chore: address review feedback | [
{
"path": "BUILD.gn",
"patch": "@@ -79,6 +79,13 @@ if (is_linux) {\n ]\n }\n \n+ # Generates electron_gtk_stubs.h header which contains\n+ # stubs for extracting function ptrs from the gtk library.\n+ # Function signatures for which stubs are required should be\n+ # declared in electron_gtk.sigs, ... | 2022-04-18T13:36:17 |
ollama/ollama | 2ae65ae471c9d51d343f401da16c05b98b99a842 | a3b6886b7da0339e63ebf41e6ba5c6b06438a123 | win: handle more than 2048 processes (#10997)
Fix an array out of bounds crash | [
{
"path": "cmd/start_windows.go",
"patch": "@@ -74,7 +74,16 @@ func isProcRunning(procName string) []uint32 {\n \t\tslog.Debug(\"failed to check for running installers\", \"error\", err)\n \t\treturn nil\n \t}\n-\tpids = pids[:ret]\n+\tif ret > uint32(len(pids)) {\n+\t\tpids = make([]uint32, ret+10)\n+\t\ti... | 2025-06-06T21:06:09 |
golang/go | e424d78c3da1732b72f9170e7c01f400926143ce | 6c25cf1c5fc063cc9ea27aa850ef0c4345f3a5b4 | internal/goos: fix bug in gengoos.go
CL 601357 mistakenly added an extra period.
Change-Id: I54db621663797f094059a4eb86bf5d9626fa59d6
GitHub-Last-Rev: c756e0a82427c44b00bd88547dc40bf88c85fc1f
GitHub-Pull-Request: golang/go#70733
Reviewed-on: https://go-review.googlesource.com/c/go/+/634517
LUCI-TryBot-Result: Go LUCI... | [
{
"path": "src/internal/goos/gengoos.go",
"patch": "@@ -17,7 +17,7 @@ import (\n var gooses []string\n \n func main() {\n-\tdata, err := os.ReadFile(\"../../internal/syslist/syslist..go\")\n+\tdata, err := os.ReadFile(\"../../internal/syslist/syslist.go\")\n \tif err != nil {\n \t\tlog.Fatal(err)\n \t}",
... | 2024-12-11T04:17:11 |
ggml-org/llama.cpp | 0988accf824e817d0e3db55c05f5f2954fbfe505 | 0033f53a072af953b457c9fd2314e6e28bd11cc7 | [SYCL] Add Q8_0 reorder optimization (~3x tg speedup on Intel Arc) (#21527)
Extend the existing reorder optimization to Q8_0. The reorder
separates scale factors from weight data for coalesced memory
access -- was implemented for Q4_0/Q4_K/Q6_K but Q8_0 was missing.
On Arc Pro B70 (Xe2), Q8_0 tg goes from 4.88 to 15.... | [
{
"path": "ggml/src/ggml-sycl/dequantize.hpp",
"patch": "@@ -143,6 +143,22 @@ static __dpct_inline__ void dequantize_q5_1(const void *vx, const int64_t ib,\n #endif // GGML_SYCL_F16\n }\n \n+static __dpct_inline__ void dequantize_q8_0_reorder(const void *d_ptr, const int64_t ib, const void *qs,\n+ ... | 2026-04-07T08:12:49 |
facebook/react | 8be5423e3bf61f88545cf90ce170aed5647b2c3c | 75a19725843486f504bcaf7617d22668a22cbf72 | Type Array.prototype.map/filter
We can now type `Array.prototype.{map,filter}`:
* The callee is ConditionallyMutable because, although the array itself is not
modified, its items flow into the lambda and may be modified there.
* The argument is ConditionallyMutable because it accepts both mutable and
immutable ... | [
{
"path": "compiler/forget/src/HIR/ObjectShape.ts",
"patch": "@@ -204,6 +204,32 @@ addObject(BUILTIN_SHAPES, BuiltInArrayId, [\n returnValueKind: ValueKind.Immutable,\n }),\n ],\n+ [\n+ \"map\",\n+ addFunction(BUILTIN_SHAPES, [], {\n+ positionalParams: [],\n+ restParam: Effect.C... | 2023-05-25T21:50:14 |
electron/electron | 37b7e347fce555836d694f36f6ee5e2ea67db049 | 9d4aceb94045cc6ff292904a1c46f3d3a09a5d55 | fix: potential crash caused by dlopen different gtk libraries (#33650) | [
{
"path": "BUILD.gn",
"patch": "@@ -43,6 +43,7 @@ if (is_mac) {\n \n if (is_linux) {\n import(\"//build/config/linux/pkg_config.gni\")\n+ import(\"//tools/generate_stubs/rules.gni\")\n \n pkg_config(\"gio_unix\") {\n packages = [ \"gio-unix-2.0\" ]\n@@ -54,6 +55,38 @@ if (is_linux) {\n \"gdk-... | 2022-04-18T04:24:32 |
ollama/ollama | c6a6d7294dd50b9216918fe72fd92bc4ae572ac0 | 2cf007c9d120583ee9ad7ad39b276f2ff81eeb62 | docs: fix typo in development.md (#10998) | [
{
"path": "docs/development.md",
"patch": "@@ -118,7 +118,7 @@ To run tests, use `go test`:\n go test ./...\n ```\n \n-> NOTE: In rare cirumstances, you may nedd to change a package using the new\n+> NOTE: In rare cirumstances, you may need to change a package using the new\n > \"synctest\" package in go1.2... | 2025-06-06T16:07:29 |
huggingface/transformers | 1e31876d0eef7d046ad5d2813f67a73026fcec9c | 3532437769f416c5cc7981c3c5f1a14f7d376360 | [voxtral] fix voxtral proc (#44132)
* fix voxtral proc
* add a comment | [
{
"path": "src/transformers/models/voxtral/processing_voxtral.py",
"patch": "@@ -147,23 +147,6 @@ def apply_chat_template(\n if kwargs.get(\"return_assistant_tokens_mask\", False):\n raise ValueError(\"continue_final_message is not compatible with return_assistant_tokens_mask.\")... | 2026-02-19T16:41:51 |
ggml-org/llama.cpp | 0033f53a072af953b457c9fd2314e6e28bd11cc7 | d0a6dfeb28a09831d904fc4d910ddb740da82834 | docs: fix typo in build.md (emdawbwebgpu -> emdawnwebgpu) (#21518) | [
{
"path": "docs/build.md",
"patch": "@@ -741,7 +741,7 @@ cmake --build build --config Release\n \n WebGPU allows cross-platform access to the GPU from supported browsers. We utilize [Emscripten](https://emscripten.org/) to compile ggml's WebGPU backend to WebAssembly. Emscripten does not officially support ... | 2026-04-07T04:37:26 |
golang/go | e0c76d95abfc1621259864adb3d101cf6f1f90fc | a9922d096f0de877fba68739b35367d4c25f6ecb | syscall: remove a wrong comment in Clearenv
The comment being removed was added by commit ff3173849e
(which predates Gerrit and Rietveld, so no CL link), and
at the time it made sense.
Since CL 148370043 (and up to the current implementation of Clearenv)
the env map, which is populated by copyenv, is actually used, s... | [
{
"path": "src/syscall/env_unix.go",
"patch": "@@ -124,7 +124,7 @@ func Setenv(key, value string) error {\n }\n \n func Clearenv() {\n-\tenvOnce.Do(copyenv) // prevent copyenv in Getenv/Setenv\n+\tenvOnce.Do(copyenv)\n \n \tenvLock.Lock()\n \tdefer envLock.Unlock()",
"additions": 1,
"deletions": 1,
... | 2024-12-10T20:10:13 |
facebook/react | ecc730c58713695143f825b3d2c4ec2ea93fc435 | 08a88912458d66a47e82d0e67fc739adbd837ac3 | [FeatureFlag] Toggle enableTreatHooksAsFunctions default to true
---
Toggle default to true, since this should be a no-op refactor.
Tests:
- test fixtures
- ran on Store + - and saw no difference in compiled output
- [diff](P744101621) with
`enableTreatHooksAsFunctions=false`
- [diff](P744105565) with
`... | [
{
"path": "compiler/forget/packages/snap/src/compiler-worker.ts",
"patch": "@@ -94,7 +94,7 @@ export async function compile(\n let panicOnBailout = true;\n let memoizeJsxElements = true;\n let enableAssumeHooksFollowRulesOfReact = false;\n- let enableTreatHooksAsFunctions = false;\n+ let e... | 2023-05-23T20:11:38 |
ollama/ollama | f15ffc432061e3d96b3412219a3a0f673b579a12 | 5f57b0ef4268a6bd9e8043d54c351a608a7e1bca | llm: Make "POST predict" error message more informative
"POST predict" basically means that the runner has crashed, which
can have many reasons. However, many people think this is a specific
error and either report only this message or group together unrelated
bugs. This replaces it with a more friendly and helpful me... | [
{
"path": "llm/server.go",
"patch": "@@ -797,7 +797,8 @@ func (s *llmServer) Completion(ctx context.Context, req CompletionRequest, fn fu\n \n \tres, err := http.DefaultClient.Do(serverReq)\n \tif err != nil {\n-\t\treturn fmt.Errorf(\"POST predict: %v\", err)\n+\t\tslog.Error(\"post predict\", \"error\", e... | 2025-05-14T00:26:46 |
electron/electron | 233a39dbc9e07f5620798323309a2d065a27c21b | 7658edfa1abb0ce9713e4848d1c1af15f8cac479 | fix: event propagation after exiting fullscreen on Windows (#33757) | [
{
"path": "shell/browser/api/electron_api_web_contents.cc",
"patch": "@@ -1342,6 +1342,11 @@ void WebContents::ExitFullscreenModeForTab(content::WebContents* source) {\n if (!owner_window_)\n return;\n \n+ // This needs to be called before we exit fullscreen on the native window,\n+ // or the contro... | 2022-04-14T10:35:36 |
huggingface/transformers | 3532437769f416c5cc7981c3c5f1a14f7d376360 | 4aa550b4c1ba163adb8274a85b232b5226ed33db | [docs] Fix typos in GenerationConfig docstring (#44143)
Fix "overriden" → "overridden", "field that are" → "fields that are",
and "Arg:" → "Args:" for consistency with the rest of the docstring.
Co-authored-by: nightcityblade <nightcityblade@gmail.com> | [
{
"path": "src/transformers/generation/configuration_utils.py",
"patch": "@@ -100,11 +100,11 @@ class GenerationConfig(PushToHubMixin):\n \n </Tip>\n \n- Note: the configuration field that are still `None` will be overriden by `GenerationConfig._get_default_generation_params()`\n+ Note: the config... | 2026-02-19T13:24:08 |
ggml-org/llama.cpp | 2e1f0a889e19a3922db57452268f4574c35c36e5 | 506200cf8b5c8419ce97d16dc8c50f4634e21ebe | ggml: add Q1_0 1-bit quantization support (CPU) (#21273)
* ggml: add Q1_0 and Q1_0_g128 1-bit quantization support (CPU)
* add generic fallback for x86
* remove Q1_0 (group size 32)
* rename Q1_0_g128 => Q1_0
* fix Q1_0 LlamaFileType Enum
* Fix trailing spaces; add generic fallback for othre backends
* Apply sug... | [
{
"path": "ggml/include/ggml.h",
"patch": "@@ -428,7 +428,8 @@ extern \"C\" {\n // GGML_TYPE_IQ4_NL_8_8 = 38,\n GGML_TYPE_MXFP4 = 39, // MXFP4 (1 block)\n GGML_TYPE_NVFP4 = 40, // NVFP4 (4 blocks, E4M3 scale)\n- GGML_TYPE_COUNT = 41,\n+ GGML_TYPE_Q1_0 = 41,\n+ ... | 2026-04-06T18:55:21 |
facebook/react | 4b877b6c661417e932056e12732e3d2697562dc8 | 7bd330e0b0d740e4ffda25a179a4d06081f1b8e7 | Updated copyright text to Copyright (c) Meta Platforms, Inc. and its … (#26830)
…affiliates.
## Summary
There were 8 different places where the copyright comment was wrong.
Rewrote from "Copyright (c) Facebook, Inc. and its affiliates." to
"Copyright (c) Meta Platforms, Inc. and its affiliates."
## How did ... | [
{
"path": "packages/react-devtools-core/src/cachedSettings.js",
"patch": "@@ -1,5 +1,5 @@\n /**\n- * Copyright (c) Facebook, Inc. and its affiliates.\n+ * Copyright (c) Meta Platforms, Inc. and its affiliates.\n *\n * This source code is licensed under the MIT license found in the\n * LICENSE file in the... | 2023-05-20T00:52:17 |
golang/go | a9922d096f0de877fba68739b35367d4c25f6ecb | 4ce116a884bd55d7046dbc999f329fa417414c00 | reflect: consistently document when value must be settable
Fixes #70760
Change-Id: Ia00723698b7e502fa2c63f8f1dbe1143af22e0a5
Reviewed-on: https://go-review.googlesource.com/c/go/+/634799
Reviewed-by: Ian Lance Taylor <iant@google.com>
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccoun... | [
{
"path": "src/reflect/map_noswiss.go",
"patch": "@@ -289,6 +289,7 @@ func (iter *MapIter) Key() Value {\n // It is equivalent to v.Set(iter.Key()), but it avoids allocating a new Value.\n // As in Go, the key must be assignable to v's type and\n // must not be derived from an unexported field.\n+// It pani... | 2024-12-11T00:10:27 |
huggingface/transformers | 4aa550b4c1ba163adb8274a85b232b5226ed33db | a6ef2a6f3549dd3267e8f5bafe4976a3217784bb | Fix gemma3n `get_audio_features` (#44040)
* fix
* re-enable tests
* fix tests I hope
* will need to fix the rest by ssh-ing to runner
* fixed?
* timm version issue, fixed
* remove | [
{
"path": "src/transformers/models/gemma3n/configuration_gemma3n.py",
"patch": "@@ -642,8 +642,6 @@ def __init__(\n tie_word_embeddings: bool | None = True,\n **kwargs,\n ):\n- super().__init__(**kwargs)\n-\n if isinstance(text_config, dict):\n text_config = Ge... | 2026-02-19T12:49:59 |
electron/electron | 16f8d713ab05fe325a664f0fd79cb41c403c9755 | 3d4d39d67b072a7c355dada2881cb6791e9e9f53 | fix: apply senderFrame details to ipcMain port event (#33756) | [
{
"path": "lib/browser/api/web-contents.ts",
"patch": "@@ -627,6 +627,7 @@ WebContents.prototype._init = function () {\n });\n \n this.on('-ipc-ports' as any, function (event: Electron.IpcMainEvent, internal: boolean, channel: string, message: any, ports: any[]) {\n+ addSenderFrameToEvent(event);\n ... | 2022-04-14T04:01:00 |
ollama/ollama | 5f57b0ef4268a6bd9e8043d54c351a608a7e1bca | aa25aff10d1ccc6dd4e85952678d63946bdf89dc | add thinking support to the api and cli (#10584)
- Both `/api/generate` and `/api/chat` now accept a `"think"`
option that allows specifying whether thinking mode should be on or
not
- Templates get passed this new option so, e.g., qwen3's template can
put `/think` or `/no_think` in the system prompt depending ... | [
{
"path": "api/types.go",
"patch": "@@ -83,6 +83,12 @@ type GenerateRequest struct {\n \t// Options lists model-specific options. For example, temperature can be\n \t// set through this field, if the model supports it.\n \tOptions map[string]any `json:\"options\"`\n+\n+\t// Think controls whether thinking/r... | 2025-05-29T02:38:52 |
ggml-org/llama.cpp | 506200cf8b5c8419ce97d16dc8c50f4634e21ebe | 15f786e6581598638840276948a7e6183fc96a83 | cli: fix stripping of \n in multiline input (#21485)
* llama-cli: fix stripping of \n in multiline input
* Change & string to string_view
* Apply suggestions from code review
Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com>
* Fix EditorConfig linter error
---------
Co-authored-by: Sigbjørn Skjæret ... | [
{
"path": "common/console.cpp",
"patch": "@@ -700,13 +700,13 @@ namespace console {\n std::vector<std::string> entries;\n size_t viewing_idx = SIZE_MAX;\n std::string backup_line; // current line before viewing history\n- void add(const std::string & line) {\n+ void add... | 2026-04-06T18:54:06 |
facebook/react | 46417a4ed77513d8e385ccd32e2103d5504bce4e | a933d5e307d82635d2b171e23da9bcb926b909b0 | Fix bug with partially memoized destructuring | [
{
"path": "compiler/forget/src/CompilerPipeline.ts",
"patch": "@@ -32,6 +32,7 @@ import {\n buildReactiveBlocks,\n buildReactiveFunction,\n codegenReactiveFunction,\n+ extractScopeDeclarationsFromDestructuring,\n flattenReactiveLoops,\n flattenScopesWithHooks,\n inferReactiveScopeVariables,\n@@... | 2023-05-18T16:25:28 |
golang/go | 4ce116a884bd55d7046dbc999f329fa417414c00 | e6de1b2debe2bc7211f6f9cac4b64d7cd90f7c4e | runtime: avoid panic in expired synctest timer chan read
When reading from time.Timer.C for an expired timer using
a fake clock (in a synctest bubble), the timer will not
be in a heap. Avoid a spurious panic claiming the timer
moved between synctest bubbles.
Drop the panic when a bubbled goroutine reads from a
non-bu... | [
{
"path": "src/internal/synctest/synctest_test.go",
"patch": "@@ -105,7 +105,7 @@ func TestMallocs(t *testing.T) {\n \t}\n }\n \n-func TestTimer(t *testing.T) {\n+func TestTimerReadBeforeDeadline(t *testing.T) {\n \tsynctest.Run(func() {\n \t\tstart := time.Now()\n \t\ttm := time.NewTimer(5 * time.Second)\n... | 2024-12-10T17:49:45 |
huggingface/transformers | a6ef2a6f3549dd3267e8f5bafe4976a3217784bb | b240061e78c6269deceb904f92c92b03bc487f76 | Fix UMT5EncoderModel embedding weights not being tied after loading (#43880)
* fix umt5 weight
Signed-off-by: jiqing-feng <jiqing.feng@intel.com>
* update config file
Signed-off-by: jiqing-feng <jiqing.feng@intel.com>
* pop tie weights for umt5
Signed-off-by: jiqing-feng <jiqing.feng@intel.com>
* update other t5... | [
{
"path": "src/transformers/models/mt5/configuration_mt5.py",
"patch": "@@ -93,7 +93,6 @@ def __init__(\n is_encoder_decoder=True,\n use_cache=True,\n tokenizer_class=\"T5Tokenizer\",\n- tie_word_embeddings=False,\n bos_token_id=None,\n pad_token_id=0,\n ... | 2026-02-19T12:42:23 |
ollama/ollama | eda472df1bd420517ca05c59ba0096e8b518fb69 | f18e0cb5508450bd14db5ec8015709d2c4ab820f | server: add hint to the error message when model path access fails (#10843) | [
{
"path": "server/modelpath.go",
"patch": "@@ -116,7 +116,7 @@ func (mp ModelPath) BaseURL() *url.URL {\n func GetManifestPath() (string, error) {\n \tpath := filepath.Join(envconfig.Models(), \"manifests\")\n \tif err := os.MkdirAll(path, 0o755); err != nil {\n-\t\treturn \"\", err\n+\t\treturn \"\", fmt.E... | 2025-05-24T20:17:04 |
electron/electron | 341b7bdf4ab7dd1a10471f57bf6f558985ff4cc0 | 4c4e02318fc651cd0a96ff79b8d146f02701a6b2 | fix: #ARGB to #RGBA conversion (#33707)
* fix: argb to rgba conversion
* chore: remove logging import
* refactor: color_str -> converted_color_str | [
{
"path": "shell/common/color_util.cc",
"patch": "@@ -16,7 +16,7 @@\n \n namespace {\n \n-bool IsHexFormat(const std::string& str) {\n+bool IsHexFormatWithAlpha(const std::string& str) {\n // Must be either #ARGB or #AARRGGBB.\n bool is_hex_length = str.length() == 5 || str.length() == 9;\n if (str[0]... | 2022-04-13T08:46:05 |
ggml-org/llama.cpp | 15f786e6581598638840276948a7e6183fc96a83 | 94ca829b6001019622c0f67fcd48e9ec6bd7dce8 | [CUDA ] Write an optimized flash_attn_stream_k_fixup kernel (#21159)
* Write an optimized flash_attn_stream_k_fixup kernel
Write a specialized and more optimized kernel for cases where nblocks_stream_k is multiple of ntiles_dst.
Make nblocks_stream_k to multiple of ntiles_dst if nblocks_stream_k > 2 * ntiles_dst
* U... | [
{
"path": "ggml/src/ggml-cuda/fattn-common.cuh",
"patch": "@@ -676,9 +676,96 @@ static __global__ void flash_attn_mask_to_KV_max(\n \n template<int D, int ncols1, int ncols2> // D == head size\n __launch_bounds__(D, 1)\n-static __global__ void flash_attn_stream_k_fixup(\n- float * __restrict__ dst, c... | 2026-04-06T18:34:29 |
facebook/react | a933d5e307d82635d2b171e23da9bcb926b909b0 | 3603ee00a65f292d9d08cf36c31a9cf5f8843467 | Repro for bug with partially memoized destructuring | [
{
"path": "compiler/forget/src/ReactiveScopes/CodegenReactiveFunction.ts",
"patch": "@@ -451,7 +451,7 @@ function codegenInstructionNullable(\n instr.value.kind === \"DeclareContext\"\n ) {\n let kind: InstructionKind = instr.value.lvalue.kind;\n- let lvalue;\n+ let lvalue: Place | Pattern;\... | 2023-05-18T16:25:24 |
golang/go | e6de1b2debe2bc7211f6f9cac4b64d7cd90f7c4e | fce17b0c774593da0dfb39b829464d1da8ceca77 | html/template: escape script tags in JS errors case insensitively
Thanks to Juho Forsén of Mattermost for reporting this issue.
Fixes #70740
Change-Id: I1a49b199dee91cd2bb4df5b174aaa958dc040c18
Reviewed-on: https://go-review.googlesource.com/c/go/+/634696
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accou... | [
{
"path": "src/html/template/js.go",
"patch": "@@ -9,6 +9,7 @@ import (\n \t\"encoding/json\"\n \t\"fmt\"\n \t\"reflect\"\n+\t\"regexp\"\n \t\"strings\"\n \t\"unicode/utf8\"\n )\n@@ -144,6 +145,8 @@ func indirectToJSONMarshaler(a any) any {\n \treturn v.Interface()\n }\n \n+var scriptTagRe = regexp.MustComp... | 2024-12-09T19:53:32 |
huggingface/transformers | b240061e78c6269deceb904f92c92b03bc487f76 | 196216c301dbf8f6199a46da9dabf8b82576824e | fix(testing): Update stale device override test in GraniteSpeech (#44113)
* fix: Return feature extractor outputs on CPU
* fix: Update stale device override test
* nit: Parameterize test
* nit: Fix ci/circleci: check_code_quality | [
{
"path": "tests/models/granite_speech/test_processing_granite_speech.py",
"patch": "@@ -25,7 +25,6 @@\n require_torch,\n require_torch_accelerator,\n require_torchaudio,\n- torch_device,\n )\n from transformers.utils import is_torchaudio_available\n \n@@ -196,11 +195,10 @@ def test_audio_tok... | 2026-02-19T11:06:22 |
ollama/ollama | 1f371ea92f7ebe4edd208b6732753473b2c4d0cd | 73d6a82cce18f84ff5c67148783224cf25b30b32 | ml: Panic rather than return error on tensor allocation failure
FromFloatSlice and FromIntSlice return an error if the shape doesn't
match the passed data or if memory can't be allocated. Since these
are inputs, the memory being allocated is system memory rather than VRAM.
In many cases, the caller can't really handl... | [
{
"path": "kvcache/causal.go",
"patch": "@@ -211,10 +211,9 @@ func (c *Causal) StartForward(ctx ml.Context, batch input.Batch, reserve bool) e\n \t\tc.curCellRange.max = len(c.cells) - 1\n \t}\n \n-\tvar err error\n-\tc.curMask, err = c.buildMask(ctx)\n+\tc.curMask = c.buildMask(ctx)\n \n-\treturn err\n+\tr... | 2025-05-19T17:43:56 |
ggml-org/llama.cpp | 941146b3f1ebcd54f125f1f80598f29231155989 | 482d862bcbf813f5a8393ac05a2c31c647fc2984 | convert : fix block_ff_dim retrieval for lfm2 (#21508) | [
{
"path": "convert_hf_to_gguf.py",
"patch": "@@ -11818,10 +11818,8 @@ class LFM2Model(TextModel):\n model_arch = gguf.MODEL_ARCH.LFM2\n \n def _add_feed_forward_length(self):\n- ff_dim = self.hparams[\"block_ff_dim\"]\n-\n+ ff_dim = self.find_hparam([\"block_ff_dim\", \"intermediate_si... | 2026-04-06T12:05:18 |
electron/electron | 59dd17f2cf0c816a718336d03667e42ca81ca187 | e8ed9cb4b507e120de8b396b1d8d88e554b7d395 | chore: bump chromium to 102.0.4989.0 (main) (#33557)
* chore: bump chromium in DEPS to 102.0.4975.0
* chore: bump chromium in DEPS to 102.0.4977.0
* chore: update patches
* Remove parameter of OnGpuProcessCrashed()
https://chromium-review.googlesource.com/c/chromium/src/+/3543396
* hid: Add exclusionFil... | [
{
"path": ".circleci/build_config.yml",
"patch": "@@ -431,17 +431,19 @@ step-get-more-space-on-mac: &step-get-more-space-on-mac\n background: true\n \n # On macOS delete all .git directories under src/ expect for\n-# third_party/angle/ because of build time generation of file\n+# third_party/angle/ and ... | 2022-04-12T11:19:14 |
golang/go | fce17b0c774593da0dfb39b829464d1da8ceca77 | d87878c62b2db318a12e5bd2126a82c117961156 | crypto/internal/fips140/ecdsa: fix reseed_counter check for HMAC_DRBG_Generate_algorithm
SP 800-90A Rev. 1 10.1.2.5 step 7 requires
reseed_counter = reseed_counter + 1
as the final step before returning SUCCESS.
This increment of reseedCounter was missing, meaning the reseed interval
check at the start of Generate w... | [
{
"path": "src/crypto/internal/fips140/ecdsa/hmacdrbg.go",
"patch": "@@ -160,4 +160,6 @@ func (d *hmacDRBG) Generate(out []byte) {\n \td.hK = d.newHMAC(K)\n \td.hK.Write(d.V)\n \td.V = d.hK.Sum(d.V[:0])\n+\n+\td.reseedCounter++\n }",
"additions": 2,
"deletions": 0,
"language": "Go"
}
] | 2024-12-10T12:52:49 |
huggingface/transformers | 556312cd45a5e619c41b0f8adf680eab0d334324 | 549835e55228ea9158ce39e7b53a740bd8461594 | docs: fix typo 'AuoQuant' → 'AutoQuant' and clarify FINEGRAINED_FP8 library column (#44131)
Two small fixes in docs/source/en/quantization/overview.md:
1. Typo: 'AuoQuant Notebook' → 'AutoQuant Notebook' in the User-Friendly
Quantization Tools section. The link text was missing the letter 't'.
2. The FINEGRAINED_... | [
{
"path": "docs/source/en/quantization/overview.md",
"patch": "@@ -40,7 +40,7 @@ Use the Space below to help you pick a quantization method depending on your har\n | [FBGEMM_FP8](./fbgemm_fp8) | 🟢 | 🔴 | 🟢 | 🔴 | 🔴 ... | 2026-02-18T20:32:16 |
ollama/ollama | 73d6a82cce18f84ff5c67148783224cf25b30b32 | 6db8a3771c29d070ef165cca0d7e8dbda3fc341e | ollamarunner: Memory usage reporting
This provides granular information about the backend memory allocations
required by the runner:
- Per backend
- Per layer
- Weights, cache and graph
- Allocation status
This can be used for debugging and validating memory estimates. | [
{
"path": "kvcache/causal_test.go",
"patch": "@@ -508,7 +508,7 @@ func (c *testContext) Forward(...ml.Tensor) ml.Context { return c }\n \n func (c *testContext) Compute(...ml.Tensor) {}\n \n-func (c *testContext) Reserve() error { return nil }\n+func (c *testContext) Reserve() {}\n \n func (c *testContext) ... | 2025-04-17T18:00:25 |
ggml-org/llama.cpp | 58190cc84d846d8575ba26e8486bc29d9fd8ad55 | af76639f728c69c74c873cc45f038aaa17afd09e | llama : correct platform-independent loading of BOOL metadata (#21428)
* model-loader : fix GGUF bool array conversion
* model-loader : fix remaining GGUF bool pointer uses | [
{
"path": "src/llama-impl.cpp",
"patch": "@@ -128,7 +128,7 @@ static std::string gguf_data_to_str(enum gguf_type type, const void * data, int\n case GGUF_TYPE_INT64: return std::to_string(((const int64_t *)data)[i]);\n case GGUF_TYPE_FLOAT32: return std::to_string(((const float *)data)... | 2026-04-05T23:40:38 |
electron/electron | 94c2a7671ca07e74d36d621d046c0f2f6d2f04f3 | 4d4682c0e38cd49add16310278726e48de9db2f5 | build: temporarily disable 32-bit Windows symbol generation (#33653)
* build: temporarily disable 32-bit Windows symbol generation
* fix: modify upload.py
* chore: fix comment
Co-authored-by: VerteDinde <vertedinde@electronjs.org> | [
{
"path": "appveyor.yml",
"patch": "@@ -174,14 +174,15 @@ build_script:\n - python %LOCAL_GOMA_DIR%\\goma_ctl.py stat\n - python electron/build/profile_toolchain.py --output-json=out/Default/windows_toolchain_profile.json\n - 7z a node_headers.zip out\\Default\\gen\\node_headers\n+ # Temporarily disa... | 2022-04-08T11:17:51 |
golang/go | d87878c62b2db318a12e5bd2126a82c117961156 | 6705ac688528b5a9ef7ec94ba04ab1f65f048a75 | runtime: make special offset a uintptr
Currently specials try to save on space by only encoding the offset from
the base of the span in a uint16. This worked fine up until Go 1.24.
- Most specials have an offset of 0 (mem profile, finalizers, etc.)
- Cleanups do not care about the offset at all, so even if it's wrong,... | [
{
"path": "src/runtime/mheap.go",
"patch": "@@ -1839,7 +1839,7 @@ const (\n type special struct {\n \t_ sys.NotInHeap\n \tnext *special // linked list in span\n-\toffset uint16 // span offset of object\n+\toffset uintptr // span offset of object\n \tkind byte // kind of special\n }\n \n@@ -1... | 2024-12-09T19:21:48 |
huggingface/transformers | 549835e55228ea9158ce39e7b53a740bd8461594 | 6976f75751ac484b51cf3c7ede5ca21109219dd7 | Update post proc (#44090)
* bos and eos behaviour should match when updating post processor
* add test
* fix | [
{
"path": "src/transformers/tokenization_utils_tokenizers.py",
"patch": "@@ -425,15 +425,12 @@ def update_post_processor(self):\n bos = self.bos_token\n bos_token_id = self.bos_token_id\n if bos is None and self.add_bos_token:\n- raise ValueError(\"add_bos_token = True but... | 2026-02-18T15:34:16 |
ollama/ollama | d950ff12c09c07a1cda7242373071fb9e7af9ddc | adff143bcda0c7ab4ca3a85dc3db5a81552368c7 | sched: fix runner leak during reloading unload (#10819)
When the same model is being reloaded rapidly with client connections
being canceled before the model finishes loading, the queued unload
event could cause a leak of runners by deleting a different runner from
the loaded list. | [
{
"path": "server/sched.go",
"patch": "@@ -387,6 +387,17 @@ func (s *Scheduler) processCompleted(ctx context.Context) {\n \t\t\t\ts.loadedMu.Unlock()\n \t\t\t\trunner.refMu.Unlock()\n \t\t\t\tslog.Debug(\"duplicate expired event, ignoring\", \"runner\", runner)\n+\t\t\t} else if runner.pid != runnerToUnload... | 2025-05-22T21:31:36 |
ggml-org/llama.cpp | af76639f728c69c74c873cc45f038aaa17afd09e | 761797ffdf2ce3f118e82c663b1ad7d935fbd656 | model : add HunyuanOCR support (#21395)
* HunyuanOCR: add support for text and vision models
- Add HunyuanOCR vision projector (perceiver-based) with Conv2d merge
- Add separate HUNYUAN_OCR chat template (content-before-role format)
- Handle HunyuanOCR's invalid pad_token_id=-1 in converter
- Fix EOS/EOT token IDs fr... | [
{
"path": "convert_hf_to_gguf.py",
"patch": "@@ -11521,13 +11521,50 @@ def prepare_tensors(self):\n raise ValueError(f\"Unprocessed experts: {experts}\")\n \n \n-@ModelBase.register(\"HunYuanDenseV1ForCausalLM\")\n+@ModelBase.register(\"HunYuanDenseV1ForCausalLM\", \"HunYuanVLForConditionalG... | 2026-04-05T21:32:14 |
electron/electron | 4d4682c0e38cd49add16310278726e48de9db2f5 | 7fb1c8faadd7a371316a6ca9986d021d333e70c3 | fix: report more detailed errors in shell.openExternal() on Windows (#33620) | [
{
"path": "shell/common/platform_util_win.cc",
"patch": "@@ -251,7 +251,8 @@ std::string OpenExternalOnWorkerThread(\n ShellExecuteW(nullptr, L\"open\", escaped_url.c_str(), nullptr,\n working_dir.empty() ? nullptr : working_dir.c_str(),\n SW_SHOWNOR... | 2022-04-07T18:07:39 |
golang/go | 07398d2e57ac5df6f95b0344252f1560376328f3 | e3e1d735287a3bab5b060415513bd64785c4e209 | weak: align weak.Pointer documentation with runtime.AddCleanup
In hindsight, I think the "advice" I wrote is a bit heavy-handed and
better suited for something like the GC guide. Listing the use-cases
seems good, and all the possible things that go wrong seems to do the
trick in terms of deterrence, like it does with ... | [
{
"path": "src/weak/doc.go",
"patch": "@@ -3,30 +3,7 @@\n // license that can be found in the LICENSE file.\n \n /*\n-Package weak provides weak pointers with the goal of memory efficiency.\n-The primary use-cases for weak pointers are for implementing caches,\n-canonicalization maps (like the unique packag... | 2024-12-07T02:58:00 |
huggingface/transformers | 6976f75751ac484b51cf3c7ede5ca21109219dd7 | 398780d3b659d648a74ce33ac1240708dc9c05cb | Fix: flaky `Kosmos2ModelTest` test (#44061)
* Fixes flakiness in `Kosmos2ModelTest::test_assisted_decoding_matches_greedy_search`
Reproduced locally with `pytest -q -m generate --random-order-bucket=none --flake-finder --flake-runs=200 tests/models/kosmos2/test_modeling_kosmos2.py -k
│ test_assisted_decoding_matche... | [
{
"path": "tests/models/kosmos2/test_modeling_kosmos2.py",
"patch": "@@ -44,6 +44,7 @@\n TEST_EAGER_MATCHES_SDPA_INFERENCE_PARAMETERIZATION,\n ModelTesterMixin,\n floats_tensor,\n+ global_rng,\n ids_tensor,\n random_attention_mask,\n )\n@@ -308,6 +309,7 @@ def setUp(self):\n s... | 2026-02-18T14:23:27 |
ggml-org/llama.cpp | 5d3a4a7da5e3dd42f5922aba2fe21b520e96e830 | c08d28d08871715fd68accffaeeb76ddcaede658 | server : fix logging of build + system info (#21460)
This PR changes the logging that occurs at startup of llama-server.
Currently, it is redundant (including CPU information twice) and it is
missing the build + commit info. | [
{
"path": "tools/server/server.cpp",
"patch": "@@ -108,10 +108,8 @@ int main(int argc, char ** argv) {\n llama_backend_init();\n llama_numa_init(params.numa);\n \n- LOG_INF(\"system info: n_threads = %d, n_threads_batch = %d, total_threads = %d\\n\", params.cpuparams.n_threads, params.cpuparams_b... | 2026-04-05T14:14:02 |
ollama/ollama | adff143bcda0c7ab4ca3a85dc3db5a81552368c7 | fbe6ae285a23baddb14c5bbce26d4fcb837503e4 | fix: mllama quality (#10807)
* fix mllama convert
- transform attn_gate and ffn_gate
- swap attention heads for vision models
* fix mllama
the mlp gate which was applied in the wrong place | [
{
"path": "convert/convert_mllama.go",
"patch": "@@ -94,7 +94,9 @@ func (m *mllamaModel) Tensors(ts []Tensor) []*ggml.Tensor {\n \tvar out []*ggml.Tensor\n \tvar text []Tensor\n \tfor _, t := range ts {\n-\t\tif t.Name() == \"v.position_embd.gate\" {\n+\t\tif !strings.HasPrefix(t.Name(), \"v.\") && !strings... | 2025-05-22T18:30:49 |
facebook/react | 329809de818366cfccf0a6a69e00191b2639efeb | 5ee23af1a6d10b79e96c6bf82a28e1bef5b0130a | Dramatically simplify InlineUseMemo
I realized a wayyyy simpler approach to inlining a lambda: wrap it in a labeled
block. The transformation is roughly as follows:
```javascript
// Before
const x = useMemo(() => {
if (a) {
return b;
}
return c;
}, [a, b, c]);
return x;
// After
let x;
label:... | [
{
"path": "compiler/forget/src/Inference/InlineUseMemo.ts",
"patch": "@@ -13,20 +13,19 @@ import {\n Environment,\n FunctionExpression,\n GeneratedSource,\n- GotoTerminal,\n GotoVariant,\n- HIR,\n HIRFunction,\n Identifier,\n IdentifierId,\n InstructionKind,\n+ LabelTerminal,\n Place,\n... | 2023-05-17T22:55:51 |
golang/go | e3e1d735287a3bab5b060415513bd64785c4e209 | e79b2e1e3acbce03b04f4ae95a8884183006bd1e | bufio: make the description of Peek's behavior better
Previously, based on the description, it was not obvious that Peek could
change the buffer. It may have been mistakenly assumed that Peek would
always return an error if n is greater than b.Buffered().
Change-Id: I095006dd2ba1c2138bb193396cb24e2dda42d771
GitHub-La... | [
{
"path": "src/bufio/bufio.go",
"patch": "@@ -133,9 +133,10 @@ func (b *Reader) readErr() error {\n }\n \n // Peek returns the next n bytes without advancing the reader. The bytes stop\n-// being valid at the next read call. If Peek returns fewer than n bytes, it\n-// also returns an error explaining why th... | 2024-12-06T21:51:36 |
huggingface/transformers | 39ddb88af05ed112819d7a636093991a584d0c65 | ddfe1c5fd050476a15dbef26a6ab82e68efdb3dc | `grouped_mm` fallback (#44043)
* more native than native grouped_mm
* all moes that set experts impl are compilable now (no need for custom! groupedmm kernel)
* more compatibility
* quick exit
* fix
* comment
* docs | [
{
"path": "docs/source/en/experts_interface.md",
"patch": "@@ -81,11 +81,12 @@ model = AutoModelForCausalLM.from_pretrained(\n \n All three backends (`\"eager\"`, `\"batched_mm\"`, `\"grouped_mm\"`) are compatible with `torch.compile` to certain extents. The following table summarizes compatibility:\n \n-| ... | 2026-02-18T10:08:15 |
ggml-org/llama.cpp | 661e9acb36768d0d4ddb6f2eb674fbb1be185823 | b8635075ffe27b135c49afb9a8b5c434bd42c502 | ci: fix vulkan workflow referencing non-existent action (#21442) | [
{
"path": ".github/workflows/build-vulkan.yml",
"patch": "@@ -72,7 +72,7 @@ jobs:\n \n - name: Setup Vulkan SDK\n if: steps.cache-sdk.outputs.cache-hit != 'true'\n- uses: ./.github/actions/linux-setup-vulkan-llvmpipe\n+ uses: ./.github/actions/linux-setup-vulkan\n with:\n... | 2026-04-05T00:59:51 |
electron/electron | 4615fc53ca3af6de585de1c25ff623169cbba5d8 | 927ab3104d9bb2b6a773d5b7a78b0da81f870b91 | chore: fix typo in NotifyWindowRequestPreferredWidth method name (#33568) | [
{
"path": "shell/browser/native_window.cc",
"patch": "@@ -479,7 +479,7 @@ void NativeWindow::SetWindowControlsOverlayRect(const gfx::Rect& overlay_rect) {\n overlay_rect_ = overlay_rect;\n }\n \n-void NativeWindow::NotifyWindowRequestPreferredWith(int* width) {\n+void NativeWindow::NotifyWindowRequestPref... | 2022-04-05T16:25:07 |
ollama/ollama | 61aeaf7e813bf307f1b28480c7ee2aed639b28f7 | 7359b0270767d1ebda33598d738a4263a4238b3a | remove support for multiple ggufs in a single file (#10722)
* remove support for multiple ggufs in a single file
this was an attempt to make it easier to import multimodal models into
ollama. this was rarely used and error prone so remove it
* fix: create fused model from blob | [
{
"path": "server/create.go",
"patch": "@@ -501,48 +501,27 @@ func ggufLayers(digest string, fn func(resp api.ProgressResponse)) ([]*layerGGML\n \t\treturn nil, errOnlyGGUFSupported\n \t}\n \n-\tstat, err := blob.Stat()\n+\tf, err := ggml.Decode(blob, -1)\n \tif err != nil {\n \t\treturn nil, err\n \t}\n \n... | 2025-05-21T20:55:31 |
facebook/react | 84a356274a86fec51dd4c46441605b2723e66c16 | f070cab87017b58f07a1b75953c7585a1bd0d5b6 | Stop shrinking HIR to preserve fallthrough nodes
This is part of a stack to fix some edge cases in inlining of useMemo closures.
In this first step, I'm disabling `shrink()` in order to retain more information
about the data flow. For example,
```
label: if (cond) {
break label;
}
return foo;
```
Woul... | [
{
"path": "compiler/forget/src/HIR/HIRBuilder.ts",
"patch": "@@ -9,7 +9,6 @@ import { Binding, NodePath } from \"@babel/traverse\";\n import * as t from \"@babel/types\";\n import invariant from \"invariant\";\n import { CompilerError } from \"../CompilerError\";\n-import { logHIR } from \"../Utils/logger\"... | 2023-05-17T22:55:50 |
golang/go | e79b2e1e3acbce03b04f4ae95a8884183006bd1e | c8fb6ae617d65b42089202040d8fbd309d1a0fe4 | cmd/go: document the build cache as safe for concurrent use
Fixes #26677
Change-Id: I2ca0408503000ccaddb0bd1fd359381ddd4fb699
Reviewed-on: https://go-review.googlesource.com/c/go/+/632895
Reviewed-by: Michael Matloob <matloob@golang.org>
Auto-Submit: Sam Thanawalla <samthanawalla@google.com>
LUCI-TryBot-Result: Go LU... | [
{
"path": "src/cmd/go/alldocs.go",
"patch": "@@ -2264,6 +2264,7 @@\n // The go command caches build outputs for reuse in future builds.\n // The default location for cache data is a subdirectory named go-build\n // in the standard user cache directory for the current operating system.\n+// The cache is safe... | 2024-12-02T18:32:36 |
huggingface/transformers | a64996e33be9d2a32b199a5e944403ecbca9fb18 | 83eb94c1febf98b25338622b14522b7288f1f3fd | Fix loading logic issue (#44095)
* correct check
* doc
* fix
* remove
* fix
* fix
* finalize
* fix
* fix
* fix | [
{
"path": "src/transformers/modeling_utils.py",
"patch": "@@ -2322,17 +2322,24 @@ def _init_weights(self, module):\n init.copy_(module.inv_freq, buffer_value)\n init.copy_(module.original_inv_freq, buffer_value)\n \n- def _initialize_weights(self, module):\n+ def _initialize_we... | 2026-02-17T19:03:49 |
ollama/ollama | 7359b0270767d1ebda33598d738a4263a4238b3a | c890011322fbdd325ef9f16e425fe1f5213a24fe | win: detect background upgrade in progress (#10785)
Give the user a helpful error instead of showing
connection refused errors. | [
{
"path": "cmd/cmd.go",
"patch": "@@ -1236,11 +1236,11 @@ func checkServerHeartbeat(cmd *cobra.Command, _ []string) error {\n \t\treturn err\n \t}\n \tif err := client.Heartbeat(cmd.Context()); err != nil {\n-\t\tif !strings.Contains(err.Error(), \" refused\") {\n+\t\tif !(strings.Contains(err.Error(), \" r... | 2025-05-21T17:46:56 |
ggml-org/llama.cpp | b8635075ffe27b135c49afb9a8b5c434bd42c502 | 9c699074c97191754c8a966298f84c79f90fce38 | common : add gemma 4 specialized parser (#21418)
* common : add gemma4 dedicated parser
* cont : add '<|tool_response>' as eog
* cont : emit JSON from Gemma4 tool call AST
* cont : more fixes
* cont : refactor convert function
* cont : refine rules and mapping
* cont : add more tests
* cont : clean up
* cont :... | [
{
"path": "common/chat-auto-parser-generator.cpp",
"patch": "@@ -8,109 +8,11 @@\n #include \"nlohmann/json.hpp\"\n #include \"peg-parser.h\"\n \n-#include <algorithm>\n #include <stdexcept>\n #include <string>\n \n using json = nlohmann::ordered_json;\n \n-namespace {\n-\n-// Gemma4-specific PEG builder ext... | 2026-04-04T18:39:00 |
electron/electron | cc3743bd43197db26411fd84a6d67fdff487c81d | fcbdaab5e3c395a844ef75f0aa766dd20b1d90e9 | fix: remove usage of private pid API on MAS (#33594) | [
{
"path": "patches/chromium/mas_no_private_api.patch",
"patch": "@@ -6,6 +6,33 @@ Subject: mas: avoid some private APIs\n Guard usages in blink of private Mac APIs by MAS_BUILD, so they can be\n excluded for people who want to submit their apps to the Mac App store.\n \n+diff --git a/base/process/process_in... | 2022-04-05T16:09:12 |
facebook/react | 8b3865198658e791c3675c5356ec14bcc4a0d826 | 7ba638ef8d7941abc5aaf4a79bea319dadf424c0 | [snap] Add jest test capabilities to snap
- delete output files when we detect input files are deleted
- enable test fixtures in nested directories
- exit with error code when we detect failures
Note that the test failure on this PR is expected and will be fixed by #1608 (or
happy to abandon that PR and fold t... | [
{
"path": "compiler/forget/packages/snap/src/compiler-worker.ts",
"patch": "@@ -6,7 +6,6 @@\n */\n \n import fs from \"fs/promises\";\n-import path from \"path\";\n import { exists } from \"./utils\";\n \n const originalConsoleError = console.error;\n@@ -32,11 +31,16 @@ export type TestResult = {\n unexp... | 2023-05-17T18:39:28 |
golang/go | c8fb6ae617d65b42089202040d8fbd309d1a0fe4 | 8c3e391573403cf1cf85b3256e99d0c0b7d79b3a | lib/wasm: provide fs.constants.O_DIRECTORY definition
CL 606658 added a constants.Get("O_DIRECTORY").Int() call at init time,
which panics in browsers because O_DIRECTORY is undefined. It needs to
be a JavaScript number to avoid that.
Fixes #70723.
Change-Id: I727240bd25b47401d14a5e1a364d460708803f1f
Reviewed-on: ht... | [
{
"path": "lib/wasm/wasm_exec.js",
"patch": "@@ -14,7 +14,7 @@\n \tif (!globalThis.fs) {\n \t\tlet outputBuf = \"\";\n \t\tglobalThis.fs = {\n-\t\t\tconstants: { O_WRONLY: -1, O_RDWR: -1, O_CREAT: -1, O_TRUNC: -1, O_APPEND: -1, O_EXCL: -1 }, // unused\n+\t\t\tconstants: { O_WRONLY: -1, O_RDWR: -1, O_CREAT: ... | 2024-12-07T22:48:27 |
ggml-org/llama.cpp | 9c699074c97191754c8a966298f84c79f90fce38 | d01f6274c01e111be2ccc39443f79884796e48fb | server: Fix undefined timing measurement errors in server context (#21201)
Co-authored-by: Dan Hoffman <dhoffman@cyket.net> | [
{
"path": "tools/server/server-context.cpp",
"patch": "@@ -155,8 +155,8 @@ struct server_slot {\n int64_t t_start_process_prompt;\n int64_t t_start_generation;\n \n- double t_prompt_processing; // ms\n- double t_token_generation; // ms\n+ double t_prompt_processing = 0.0; // ms\n+ doubl... | 2026-04-04T14:11:19 |
ollama/ollama | e0ed984cde1f6191e38ac2d7f4415ffd619a631f | 139f84cf21f8d8107f69c1404f17a8840c6d67d0 | feat: qwen3 dense and sparse models (#10708)
* feat: qwen3 dense
* feat: qwen3moe
* fix llama4 moe | [
{
"path": "ml/backend.go",
"patch": "@@ -128,6 +128,8 @@ type Tensor interface {\n \tNeg(ctx Context) Tensor\n \tAdd(ctx Context, t2 Tensor) Tensor\n \tMul(ctx Context, t2 Tensor) Tensor\n+\tDiv(ctx Context, t2 Tensor) Tensor\n+\n \tMulmat(ctx Context, t2 Tensor) Tensor\n \tMulmatFullPrec(ctx Context, t2 Te... | 2025-05-21T17:21:07 |
huggingface/transformers | 0e5516d6c072dd1604281ddc185d5b6ca37f0129 | 4e0573b3d942139095a88e16ea94b8a2e6bee602 | [docs] refactor tokenizer docs (#43900)
* refactor tokenizer docs
* fix
* feedback
* link
* toctree | [
{
"path": "docs/source/en/_toctree.yml",
"patch": "@@ -35,6 +35,8 @@\n title: Tokenizers\n - local: custom_tokenizers\n title: Customizing tokenizers\n+ - local: tokenizer_summary\n+ title: Summary of the tokenizers\n - local: image_processors\n title: Image processors\n ... | 2026-02-17T17:49:56 |
electron/electron | fcbdaab5e3c395a844ef75f0aa766dd20b1d90e9 | a72acfc5355a9e5737be3543b65d2d03f1246e30 | fix: add missing translation string for ax tree (#33614) | [
{
"path": "electron_strings.grdp",
"patch": "@@ -145,4 +145,16 @@\n </message>\n <message name=\"IDS_HID_CHOOSER_ITEM_WITHOUT_NAME\" desc=\"User option displaying the device IDs for a Human Interface Device (HID) without a device name.\">\n Unknown Device (<ph name=\"DEVICE_ID\">$1<ex>1234:abcd<... | 2022-04-05T03:22:36 |
facebook/react | 7ba638ef8d7941abc5aaf4a79bea319dadf424c0 | 0b697d1903318b75c1e61b749365a44d39d67ebb | [tests] delete stale .expect files
---
Looks like we delete `.js` files but missed `.expect` files. Jest probably
didn't catch this because the basename of the fixtures had duplicates (in
rule-of-hooks) | [
{
"path": "compiler/forget/src/__tests__/fixtures/compiler/error.invalid-hook-after-early-return.expect.md",
"patch": "@@ -1,21 +0,0 @@\n-\n-## Input\n-\n-```javascript\n-function Component(props) {\n- if (props.cond) {\n- return null;\n- }\n- return useHook();\n-}\n-\n-```\n-\n-\n-## Error\n-\n-```\n... | 2023-05-17T18:39:28 |
golang/go | 312f7c1bd300d374f7078c4449c5ad142e0c3a5e | 0d453232db9c4eeea5faa7dd171b95a59619f160 | runtime: add note that Callers never returns an entry PC
The presence of a pc > entry check in CallersFrame implies we might
actually see pc == entry, when in reality Callers will never return such
a PC. This check is actually just a safety check for avoid reporting
completely nonsensical from bad input.
all.bash rep... | [
{
"path": "src/runtime/symtab.go",
"patch": "@@ -118,11 +118,16 @@ func (ci *Frames) Next() (frame Frame, more bool) {\n \t\t}\n \t\tf := funcInfo._Func()\n \t\tentry := f.Entry()\n+\t\t// We store the pc of the start of the instruction following\n+\t\t// the instruction in question (the call or the inline ... | 2024-12-06T20:37:34 |
ggml-org/llama.cpp | d006858316d4650bb4da0c6923294ccd741caefd | e43970099269b5b6da36b8977ad47697602e4e54 | ggml-webgpu: move from parameter buffer pool to single buffer with offsets (#21278)
* Work towards removing bitcast
* Move rest of existing types over
* Add timeout back to wait and remove synchronous set_tensor/memset_tensor
* move to unpackf16 for wider compatibility
* cleanup
* Remove deadlock condition in fre... | [
{
"path": "ggml/src/ggml-webgpu/ggml-webgpu-shader-lib.hpp",
"patch": "@@ -437,12 +437,18 @@ inline uint32_t ggml_webgpu_flash_attn_pick_vec_ne(const ggml_webgpu_flash_attn_\n \n // Head-dim specializations used by the tuned vec f16 path.\n switch (key.head_dim_qk) {\n- case 64: return 2u;\n-... | 2026-04-03T18:40:14 |
ollama/ollama | 139f84cf21f8d8107f69c1404f17a8840c6d67d0 | 375839ea2d05a056d02f934f02e953b41f1d444d | fix cmakelists (#10804)
this fixes an issue introduced in #10788 | [
{
"path": "CMakeLists.txt",
"patch": "@@ -51,7 +51,7 @@ include_directories(${CMAKE_CURRENT_SOURCE_DIR}/ml/backend/ggml/ggml/src/include\n include_directories(${CMAKE_CURRENT_SOURCE_DIR}/ml/backend/ggml/ggml/src/ggml-cpu)\n include_directories(${CMAKE_CURRENT_SOURCE_DIR}/ml/backend/ggml/ggml/src/ggml-cpu/am... | 2025-05-21T16:52:52 |
huggingface/transformers | 4e0573b3d942139095a88e16ea94b8a2e6bee602 | b19817bc208ad59202b6afa84b440defc5296da9 | Fix percentage formatting in help messages for gradient checkpointing, Liger Kernel, and empty cache steps (#44100) | [
{
"path": "src/transformers/training_args.py",
"patch": "@@ -896,7 +896,7 @@ class TrainingArguments:\n gradient_checkpointing: bool = field(\n default=False,\n metadata={\n- \"help\": \"Enable gradient checkpointing to trade compute for memory. Reduces memory at the cost of ~... | 2026-02-17T17:27:14 |
electron/electron | a72acfc5355a9e5737be3543b65d2d03f1246e30 | 477aa389e650d3dd2c3658b349f9a550201e6abb | fix: revert "fix: some frameless windows showing a frame on Windows (#32692)" (#33599)
This reverts commit 7c701367c0820691e2a0f8f1cfd1fb3470071704. | [
{
"path": "shell/browser/native_window_views.cc",
"patch": "@@ -340,14 +340,15 @@ NativeWindowViews::NativeWindowViews(const gin_helper::Dictionary& options,\n // Set Window style so that we get a minimize and maximize animation when\n // frameless.\n DWORD frame_style = WS_CAPTION | WS_OVERLAPP... | 2022-04-05T00:01:12 |
facebook/react | d7a98a5e97c3512ba43dd809337ae1691df1ae66 | 2468a87358de55137508e777846746091d7a1514 | Fix strict mode badge URL (#26825)
## Summary
Closes https://github.com/facebook/react/issues/26821
[[Fix #26821]](https://github.com/facebook/react/issues/26821) Update
strict mode badge URL
Updated the URL in the strict mode badge to point to the correct React
documentation for StrictMode. The previous UR... | [
{
"path": "packages/react-devtools-shared/src/devtools/views/Components/InspectedElement.js",
"patch": "@@ -237,7 +237,7 @@ export default function InspectedElementWrapper(_: Props): React.Node {\n strictModeBadge = (\n <a\n className={styles.StrictModeNonCompliant}\n- href=\"https:... | 2023-05-17T12:34:34 |
ggml-org/llama.cpp | e43970099269b5b6da36b8977ad47697602e4e54 | 50e0ad08fb6906fda9ac2e256e43a4bbf9c85639 | ci: Add Windows Vulkan backend testing on Intel (#21292)
* experimenting CI
* Experimenting CI fix for MinGW
* experimenting CI on Windows
* modified script for integration with VisualStudio
* added proxy handling
* adding python version for Windows execution
* fix iterator::end() dereference
* fixed proxy hand... | [
{
"path": ".github/workflows/build-self-hosted.yml",
"patch": "@@ -213,6 +213,27 @@ jobs:\n vulkaninfo --summary\n GG_BUILD_VULKAN=1 bash ./ci/run.sh ~/results/llama.cpp ~/mnt/llama.cpp\n \n+ ggml-ci-win-intel-vulkan:\n+ runs-on: [self-hosted, Windows, X64, Intel]\n+\n+ steps:\n+ ... | 2026-04-03T17:16:44 |
golang/go | 0d453232db9c4eeea5faa7dd171b95a59619f160 | 35caf4130eafaafb0f30bb4feeeb61ed0df37596 | cmd/internal/goobj: add missing symbol align field in top level doc
Fix the documentation of the symbol's align field that is present in the
code but not in the top level documentation
Change-Id: I753f2379b22487899ceee8ebc9c2e659d74ea986
Reviewed-on: https://go-review.googlesource.com/c/go/+/633777
Reviewed-by: Ian L... | [
{
"path": "src/cmd/internal/goobj/objfile.go",
"patch": "@@ -55,6 +55,7 @@ import (\n // Flag uint8\n // Flag2 uint8\n // Size uint32\n+// Align uint32\n // }\n // Hashed64Defs [...]struct { // short hashed (content-addressable) symbol definitions\n // ... // same as Sy... | 2024-12-06T13:06:36 |
ollama/ollama | 375839ea2d05a056d02f934f02e953b41f1d444d | 69b2fe9282323a57cd3557bed9b598b465d1b3a6 | chore: disable debug in binary libraries (#10788) | [
{
"path": "CMakeLists.txt",
"patch": "@@ -51,6 +51,8 @@ include_directories(${CMAKE_CURRENT_SOURCE_DIR}/ml/backend/ggml/ggml/src/include\n include_directories(${CMAKE_CURRENT_SOURCE_DIR}/ml/backend/ggml/ggml/src/ggml-cpu)\n include_directories(${CMAKE_CURRENT_SOURCE_DIR}/ml/backend/ggml/ggml/src/ggml-cpu/am... | 2025-05-21T16:39:38 |
facebook/react | 2468a87358de55137508e777846746091d7a1514 | f8de255e94540f9018d8196b3a34da500707c39b | React DevTools 4.27.7 -> 4.27.8 (#26823)
Closes https://github.com/facebook/react/issues/26787,
https://github.com/facebook/react/issues/26793
Includes these changes:
* fix[devtools]: fixed duplicated backend activation with multiple
renderers ([hoxyq](https://github.com/hoxyq) in
[#26807](https://github.com/fa... | [
{
"path": "packages/react-devtools-core/package.json",
"patch": "@@ -1,6 +1,6 @@\n {\n \"name\": \"react-devtools-core\",\n- \"version\": \"4.27.7\",\n+ \"version\": \"4.27.8\",\n \"description\": \"Use react-devtools outside of the browser\",\n \"license\": \"MIT\",\n \"main\": \"./dist/backend.j... | 2023-05-17T10:40:50 |
huggingface/transformers | cfef7f1401c3eadc5cb8b03cdac737ba2ca92b36 | 4355bc790e473e9a158f0b33001b192fd8b63a34 | Remove unused dependencies (#43904)
* Remove unused dependencies
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Update min versions for two packages
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Fix importlib_metadata
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
---------
Signed-off-by: Yuany... | [
{
"path": "setup.py",
"patch": "@@ -78,7 +78,6 @@\n \"codecarbon>=2.8.1\",\n \"datasets>=2.15.0\", # We need either this pin or pyarrow<21.0.0\n \"deepspeed>=0.9.3\",\n- \"diffusers\",\n \"dill<0.3.5\",\n \"evaluate>=0.4.6\",\n \"faiss-cpu\",\n@@ -88,7 +87,6 @@\n \"GitPython<... | 2026-02-17T11:39:36 |
electron/electron | 204b53e7b8cb13080b10eccf69afe17bd0893bee | 0ac6d745368492440fc39c6f12b465388851f73e | build: upload to AZ as well as S3 (#33573)
* build: upload to AZ aswell as S3
* fix: provide env to azput | [
{
"path": "package.json",
"patch": "@@ -4,6 +4,7 @@\n \"repository\": \"https://github.com/electron/electron\",\n \"description\": \"Build cross platform desktop apps with JavaScript, HTML, and CSS\",\n \"devDependencies\": {\n+ \"@azure/storage-blob\": \"^12.9.0\",\n \"@electron/docs-parser\":... | 2022-04-04T09:32:57 |
ggml-org/llama.cpp | 50e0ad08fb6906fda9ac2e256e43a4bbf9c85639 | f1f793ad0663a223d3f4f7f3d14875a009d59f5a | server: save and clear idle slots on new task (`--clear-idle`) (#20993)
* server: clear idle slots KV from VRAM (LLAMA_KV_KEEP_ONLY_ACTIVE)
* server: move idle slot KV clearing to slot release
The save "cost" is now paid by the finishing request.
* server: add --kv-clear-idle flag, enable by default
* server: skip... | [
{
"path": "common/arg.cpp",
"patch": "@@ -1311,6 +1311,14 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n params.kv_unified = value;\n }\n ).set_env(\"LLAMA_ARG_KV_UNIFIED\").set_examples({LLAMA_EXAMPLE_SERVER, LLAMA_EXAMPLE_PERPLEXITY, LLAMA_EXA... | 2026-04-03T17:02:27 |
golang/go | 2440717918434aee8450757c160cea5280d0bbe3 | 1a193b43a22a67256c7da73c30504d4107e4a64d | cmd/go: report tool errors in go list all
Before tools there was no way to directly import a package in another
module, and so missing packages were always marked as "all" due to being
dependencies of a package in a main module.
Tools break that assumption, and so to report errors in tool packages
correctly we need t... | [
{
"path": "src/cmd/go/internal/modload/load.go",
"patch": "@@ -1852,6 +1852,12 @@ func (ld *loader) load(ctx context.Context, pkg *loadPkg) {\n \n \tvar modroot string\n \tpkg.mod, modroot, pkg.dir, pkg.altMods, pkg.err = importFromModules(ctx, pkg.path, ld.requirements, mg, ld.skipImportModFiles)\n+\tif Ma... | 2024-12-06T05:25:14 |
ollama/ollama | 69b2fe9282323a57cd3557bed9b598b465d1b3a6 | 9ed8bf14cb885509281d63731cda16637a7e0bd2 | fix: qwen25vl assign samebatch in multimodal input (#10789)
setting samebatch on the vision start token is problematic because it
will be shared with other inputs that also use images. this will cause
the input to be cached and the runner will not see SameBatch. SameBatch
will also be incorrect since it may be for a d... | [
{
"path": "model/models/qwen25vl/model.go",
"patch": "@@ -121,13 +121,14 @@ func (m *Model) PostTokenize(inputs []input.Input) ([]input.Input, error) {\n \t\t\tpatchesPerChunk := inp.Multimodal[0].Tensor.Dim(1)\n \n \t\t\t// First add the vision start token\n-\t\t\tresult = append(result, input.Input{Token:... | 2025-05-21T16:39:20 |
facebook/react | 4bfcd02b2cebcb390f5aff0d7747c60a55012d5d | 4cd7065665ea2cf33c306265c8d817904bb401ca | Fix Suspense throttling mechanism (#26802)
The throttling mechanism for fallbacks should apply to both their
appearance _and_ disappearance.
This was mostly addressed by #26611. See that PR for additional context.
However, a flaw in the implementation is that we only update the the
timestamp used for throttlin... | [
{
"path": "packages/react-reconciler/src/ReactFiberCommitWork.js",
"patch": "@@ -55,6 +55,7 @@ import {\n enableLegacyHidden,\n enableHostSingletons,\n diffInCommitPhase,\n+ alwaysThrottleRetries,\n } from 'shared/ReactFeatureFlags';\n import {\n FunctionComponent,\n@@ -2905,17 +2906,35 @@ function... | 2023-05-16T19:03:30 |
huggingface/transformers | 4355bc790e473e9a158f0b33001b192fd8b63a34 | 48ad2d5b0f2860578dffac2455c2759216cb7c4a | Fix patchtsmixer call to post_init (#44082)
* always call it
* remove from tests as well | [
{
"path": "src/transformers/models/patchtsmixer/configuration_patchtsmixer.py",
"patch": "@@ -82,9 +82,6 @@ class PatchTSMixerConfig(PreTrainedConfig):\n error \"mse\".\n init_std (`float`, *optional*, defaults to 0.02):\n The standard deviation of the truncated normal weight... | 2026-02-17T11:05:37 |
ggml-org/llama.cpp | f1f793ad0663a223d3f4f7f3d14875a009d59f5a | af5c13841fb9c2a708af505105cc611e0cc9db51 | common/parser: fix call ID detection (Mistral parser mostly) + atomicity for tag-json parsers (#21230)
* Fix call ID detection (Mistral parser mostly) + atomicity for tag-json parsers
* Rename
* Update common/chat-auto-parser-generator.cpp
Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com>
---------
C... | [
{
"path": "common/chat-auto-parser-generator.cpp",
"patch": "@@ -6,6 +6,7 @@\n #include \"json-schema-to-grammar.h\"\n #include \"log.h\"\n #include \"nlohmann/json.hpp\"\n+#include \"peg-parser.h\"\n \n #include <algorithm>\n #include <stdexcept>\n@@ -317,6 +318,44 @@ common_peg_parser analyze_tools::build... | 2026-04-03T15:51:52 |
electron/electron | 78a3752adef43fa78c6c6b0805d9d1e10d147949 | 9207c2aa685a8eec69a83673ed0d2dee2b095281 | fix: create `userData` on requestSingleInstanceLock() if needed (#33559)
* test: use custom userData folder for requestSingleInstanceLock()
* update test
* prefix test folder path
* fix: create userDataDir on requestSingleInstanceLock() if needed
* Trigger Build | [
{
"path": "shell/browser/api/electron_api_app.cc",
"patch": "@@ -1148,6 +1148,8 @@ bool App::RequestSingleInstanceLock(gin::Arguments* args) {\n \n base::FilePath user_dir;\n base::PathService::Get(chrome::DIR_USER_DATA, &user_dir);\n+ // The user_dir may not have been created yet.\n+ base::CreateDire... | 2022-04-04T01:39:55 |
golang/go | 1a193b43a22a67256c7da73c30504d4107e4a64d | 18bbcffc46ce9d681190562f9430cd6727978254 | cmd/go: use AppendPath(OrigEnv) as env for tool executable
Before this change, when go tool wass used to start a tool defined in a
go.mod tool directive, it used the environment the go command was
running in. The issue with doing that is that the go command sets
various environment variables from the computed environm... | [
{
"path": "src/cmd/go/internal/tool/tool.go",
"patch": "@@ -309,12 +309,18 @@ func runBuiltTool(b *work.Builder, ctx context.Context, a *work.Action) error {\n \t\treturn nil\n \t}\n \n+\t// Use same environment go run uses to start the executable:\n+\t// the original environment with cfg.GOROOTbin added to... | 2024-11-26T01:29:11 |
ollama/ollama | e6a800ca11cb52b24fa5afc5245ed1277811fbe9 | ff180c3466e7f3ee21658465958c9ece6de2d5c0 | llama: fix incorrect initialization of C.struct_common_sampler_cparams.penalty_present (#10779) | [
{
"path": "llama/llama.go",
"patch": "@@ -544,7 +544,7 @@ func NewSamplingContext(model *Model, params SamplingParams) (*SamplingContext,\n \tcparams.penalty_last_n = C.int32_t(params.RepeatLastN)\n \tcparams.penalty_repeat = C.float(params.PenaltyRepeat)\n \tcparams.penalty_freq = C.float(params.PenaltyFre... | 2025-05-20T17:41:15 |
facebook/react | 8bf1ec97a40e04a95dcc9bb1a576e707d8c585db | f57ed15a332b8963775351359153d8059c26d0ce | Add flag back for inlineUseMemo
Reverts #1502, but flips test flags (e.g. `inlineUseMemo` by default, unless a
test specifies `@inlineUseMemo false`. I figured this add less thrash for test
fixtures, but happy to just do a clean revert (or remove the pragma altogether
and always pass `inlineUseMemo: true`) | [
{
"path": "compiler/forget/src/CompilerPipeline.ts",
"patch": "@@ -66,8 +66,10 @@ export function* run(\n const hir = lower(func, env).unwrap();\n yield log({ kind: \"hir\", name: \"HIR\", value: hir });\n \n- inlineUseMemo(hir);\n- yield log({ kind: \"hir\", name: \"RewriteUseMemo\", value: hir });\n... | 2023-05-15T18:27:26 |
ggml-org/llama.cpp | af5c13841fb9c2a708af505105cc611e0cc9db51 | 277ff5fff79d49cc3d2292ddf410ca95dd51c3a9 | common : fix tool call type detection for nullable and enum schemas (#21327)
* common : fix tool call type detection for nullable and enum schemas
* common, tests : fix grammar delegation for nullable/enum schemas and add tests
Fix enum type inference to scan all enum values (not just index 0) so
schemas like {"enum... | [
{
"path": "common/chat-auto-parser-generator.cpp",
"patch": "@@ -400,12 +400,34 @@ common_peg_parser analyze_tools::build_tool_parser_tag_tagged(parser_build_conte\n for (const auto & [param_name, param_schema] : properties.items()) {\n bool is_required = required.find(param_name)... | 2026-04-03T15:51:23 |
huggingface/transformers | 48ad2d5b0f2860578dffac2455c2759216cb7c4a | 16a3bea3b88e0530f78d4d7a2fcc0f6387ac72b9 | Fix false positive right-padding warning for decoder-only models in pipeline (#44021)
* Fix false positive right-padding warning for decoder-only models
Two changes to fix the spurious 'right-padding was detected' warning
that fires for Qwen3 and other models during batched pipeline inference:
1. TextGenerationPipel... | [
{
"path": "src/transformers/generation/utils.py",
"patch": "@@ -2535,16 +2535,22 @@ def generate(\n if not self.config.is_encoder_decoder:\n # If `input_ids` was given, check if the last id in any sequence is `pad_token_id`\n # Note: If using, `inputs_embeds` this check does ... | 2026-02-17T10:41:32 |
golang/go | d3d4e7b0d10d5587093b769ed600bd3b0a3fd9c1 | 3ae00f5d29e896d727670ca6414e84b0cd9ec0bc | testing: fix divide by zero when benchmark is faster than OS's clock resolution
I did not added a test because `benchmark_test.go` is `package testing_test`
and I don't care to change that because calling predictN is not testing the
thing I would want to test.
Ideally we would run benchmark in a VM with a highjacked ... | [
{
"path": "src/testing/benchmark.go",
"patch": "@@ -275,6 +275,11 @@ func (b *B) doBench() BenchmarkResult {\n }\n \n func predictN(goalns int64, prevIters int64, prevns int64, last int64) int {\n+\tif prevns == 0 {\n+\t\t// Round up to dodge divide by zero. See https://go.dev/issue/70709.\n+\t\tprevns = 1\... | 2024-12-06T05:51:04 |
ollama/ollama | ff180c3466e7f3ee21658465958c9ece6de2d5c0 | 3fe74fba42b8d496a1ab3e8298bdc9b8ffb0f336 | fix llama and mistral3 models (#10774)
* fix llama model
* fix mistral3.1 model
do not set default vision layers | [
{
"path": "model/models/llama/model.go",
"patch": "@@ -1,9 +1,8 @@\n package llama\n \n import (\n-\t\"fmt\"\n+\t\"cmp\"\n \t\"math\"\n-\t\"strings\"\n \n \t\"github.com/ollama/ollama/fs\"\n \t\"github.com/ollama/ollama/kvcache\"\n@@ -14,9 +13,9 @@ import (\n )\n \n type Options struct {\n-\thiddenSize, num... | 2025-05-19T22:06:35 |
facebook/react | f57ed15a332b8963775351359153d8059c26d0ce | 41a897797d92d1e5d43826da8340495b347f2f4f | [Babel] Log errors to stdout, not stderr
Writing to stderr causes buck to fail compilation.. which is not we want. Let's
log to stdout only for now. | [
{
"path": "compiler/forget/src/Babel/BabelPlugin.ts",
"patch": "@@ -109,7 +109,7 @@ export default function ReactForgetBabelPlugin(\n ) {\n throw err;\n } else {\n- console.error(formatErrorsForConsole(err, pass.filename ?? null));\n+ console.log(formatErrorsForConsole(err,... | 2023-05-15T13:45:26 |
ggml-org/llama.cpp | d3416a4aa9a37d9a0ca547e18c0e126bfe8a07ea | 43a4ee4a2cf25de0428d618544b877731d4d3713 | fix: remove stale assert (#21369) | [
{
"path": "src/llama-vocab.cpp",
"patch": "@@ -3712,9 +3712,7 @@ int llama_vocab::max_token_len() const {\n \n int llama_vocab::find_bpe_rank(const std::string & token_left, const std::string & token_right) const {\n GGML_ASSERT(token_left.find(' ') == std::string::npos);\n- GGML_ASSERT(token_left.... | 2026-04-03T11:40:41 |
huggingface/transformers | 16a3bea3b88e0530f78d4d7a2fcc0f6387ac72b9 | b3fd59f2c162af8ddb15b9af4db89c17711e4dc1 | Fix unprotected torch import (#44055)
* fix import
* oupsi | [
{
"path": "src/transformers/models/vibevoice_acoustic_tokenizer/feature_extraction_vibevoice_acoustic_tokenizer.py",
"patch": "@@ -12,18 +12,20 @@\n # See the License for the specific language governing permissions and\n # limitations under the License.\n \n-\n-import torch\n-\n from ...audio_utils import A... | 2026-02-16T18:34:06 |
ollama/ollama | 3fe74fba42b8d496a1ab3e8298bdc9b8ffb0f336 | 1a0cfd080a2d3e65519c241b7561bf5aa49468ff | llm: Use first layer as memory buffer in estimation
This is a partial revert of 0478d44 "Fixed over vram allcation dure to
small initial layer sizes."
Previously we used the size of the first layer as an extra reserved
amount of space to buffer our memory estimates. The above commit
changed this to use the largest la... | [
{
"path": "llm/memory.go",
"patch": "@@ -1,12 +1,9 @@\n package llm\n \n import (\n-\t\"cmp\"\n \t\"fmt\"\n \t\"log/slog\"\n-\t\"maps\"\n \t\"os\"\n-\t\"slices\"\n \t\"strconv\"\n \t\"strings\"\n \n@@ -125,10 +122,12 @@ func EstimateGPULayers(gpus []discover.GpuInfo, f *ggml.GGML, projectors []strin\n \t}\n... | 2025-05-19T18:40:44 |
golang/go | 5213e1e56c17bde612398dac8a2996bf020fe542 | 32e19fc4397142b743646ff8a526d07c126bf89b | testing: improve documentation, examples, release notes for
testing.b.Loop.
This CL added documentation of the no-inlining semantic of b.Loop, with
a concrete example. This CL also tries to improve the release note to be
more descriptive.
Fixes #61515
Change-Id: I1e13cc92d5d6bdbf40fb44f44475e249747b807f
Reviewed-on... | [
{
"path": "doc/next/6-stdlib/6-testing-bloop.md",
"patch": "@@ -0,0 +1,5 @@\n+### New benchmark function\n+\n+Benchmarks may now use the faster and less error-prone [testing.B.Loop] method to perform benchmark iterations like `for b.Loop() { ... }` in place of the typical loop structures involving `b.N` lik... | 2024-12-04T20:11:18 |
Subsets and Splits
Assembly Language GitHub Issues
Retrieves a sample of assembly-language related commits with their details, but doesn't provide meaningful analysis or patterns beyond basic filtering.
Swift Compiler Issues Analysis
Retrieves all training data for the Swift programming language repository, providing basic filtering but offering limited analytical insight beyond identifying relevant code examples.